@@ -13,7 +13,7 @@ use MySQL::Workbench::Parser;
 
 # ABSTRACT: create DBIC scheme for MySQL workbench .mwb files
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 has output_path              => ( is => 'ro', required => 1, default => sub { '.' } );
 has file                     => ( is => 'ro', required => 1 );
@@ -100,7 +100,7 @@ sub create_schema{
 
     my @files;
     for my $table ( @tables ){
-        my $custom_code = $self->_custom_code( $table );
+        my $custom_code = $self->_custom_code_table( $table );
         push @files, $self->_class_template( $table, $relations{$table->name}, $custom_code );
     }
 
@@ -109,7 +109,7 @@ sub create_schema{
     $self->_write_files( @files );
 }
 
-sub _custom_code {
+sub _custom_code_table {
     my ($self, $table) = @_;
 
     my $name = $table->name;
@@ -131,6 +131,12 @@ sub _custom_code {
 
     return '' if !-f $path;
 
+    return $self->_custom_code( $path );
+}
+
+sub _custom_code {
+    my ($self, $path) = @_;
+
     my $content = do { local (@ARGV, $/) = $path; <> };
 
     my ($code) = $content =~ m{
@@ -557,6 +563,15 @@ sub _main_template{
         1;
     } or warn $@;
 
+    my $custom_code;
+    if ( $version ) {
+        (my $path       = $namespace) =~ s{::}{/}g;
+        my $schema_file = $self->output_path . '/' . $path . '.pm';
+        $custom_code    = $self->_custom_code( $schema_file );
+    }
+
+    $custom_code //= '';
+
     my %all_namespaces_to_load;
     if ( $self->resultset_namespace ) {
         push @{ $all_namespaces_to_load{resultset_namespace} }, sprintf "'%s'", $self->resultset_namespace;
@@ -569,10 +584,6 @@ sub _main_template{
                 $self->load_resultset_namespace;
     }
 
-    if ( $self->result_namespace ) {
-        push @{ $all_namespaces_to_load{result_namespace} }, sprintf "'%s'", $self->result_namespace;
-    }
-
     if ( $self->load_result_namespace ) {
         push @{ $all_namespaces_to_load{result_namespace} }, map { "'$_'" }
             ref $self->load_result_namespace ?
@@ -580,6 +591,12 @@ sub _main_template{
                 $self->load_result_namespace;
     }
 
+    if ( $self->result_namespace ) {
+        my $namespace = sprintf "'%s::Result'", $self->result_namespace;
+        my $found     = grep { $namespace eq $_ }@{ $all_namespaces_to_load{result_namespace} };
+        unshift @{ $all_namespaces_to_load{result_namespace} }, $namespace if !$found;
+    }
+
     if ( $version ) {
         $version += $self->version_add || 0.01;
     }
@@ -615,6 +632,12 @@ our \$VERSION = $version;
 
 __PACKAGE__->load_namespaces$namespaces_to_load;
 
+# ---
+# Put your own code below this comment
+# ---
+$custom_code
+# ---
+
 1;~;
 
     return $namespace, $template;
@@ -635,7 +658,7 @@ MySQL::Workbench::DBIC - create DBIC scheme for MySQL workbench .mwb files
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
